# CodePen Downloader

A hacky downloader for [codepen.io](https://codepen.io). Uses requests and bs4 to extract relevant data and jinja2 to construct local copies.

Really basic, currently doesn't handle any compiling, preprocessing, etc.

## Usage

`pip install cpen`

`cpen <url> <target folder>`
